package com.steerinfo.dil.util;

import com.steerinfo.dil.wsdl.WSJJBoomFacadeSrvProxyServiceLocator;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;

import java.util.List;

/**
 * @ author    :TXF
 * @ time      :2022/2/10 10:07
 */

public class KDWebserviceUtil {
    /**
     *
     * 推送数据给金蝶接口
     * @Author TXF
     * @Date 2022/2/10 17:16
     * @param dataList 9个数据
     * @return Integer   1 成功  0 失败
     **/
    public static int sendMesToKD(List<String> dataList, String orderNumber){
        try {
            String xml = asXmlData(dataList);
            Log4jUtils.toLoggerInfo(xml);
            WSJJBoomFacadeSrvProxyServiceLocator locator = new WSJJBoomFacadeSrvProxyServiceLocator();
            String res = locator.getWSJJBoomFacade().transferEASInterfaceMethod(xml,"weighSoucNew");
            if("OK".equals(res)){
                return 1;
            }else {
                Log4jUtils.toLoggerWarning(orderNumber+ "数据推送金蝶失败："+ res);
                return 0;
            }
        } catch (Exception e) {
            Log4jUtils.toLoggerWarning(orderNumber + "数据推送金蝶失败：" + e.getMessage());
            return 0;
        }
    }


    /**
     * 创建计量数据 金蝶xml格式字符串
     * @Author TXF
     * @Date 2022/2/10 17:32
     * @param dataList
     * @return
     **/
    public static String asXmlData(List<String> dataList){
        // 创建一个Document实例
        Document doc = DocumentHelper.createDocument();
        // 添加根节点
        Element table = doc.addElement("table");
        //添加第子节点
        table.addElement("rowCount").addText("1");
        int size = dataList.size();
        table.addElement("headCount").addText(size + "");
        Element head = table.addElement("head");
        //添加body下的r1下的子节点
        Element r1 = table.addElement("body").addElement("r1");
        //添加head的子节点
        for (int i = 0; i < size; i++) {
            head.addElement("h" + (i + 1)).addText(dataList.get(i));
            r1.addElement("r1c" + (i + 1)).addText(dataList.get(i));
        }
        return doc.asXML();
    }


}




/**
 * 封装的访问webservice的工具类:（有局限性，数据量小的xml报文可用，较大则会出现stackoverflow的异常）
 *
 * @param reqXML
 *            请求的xml
 * @param endPoint
 *            webservice的路径除去?wsdl:例如：http://1.202.235.66:7002/webService/PartsService（没有?wsdl）
 * @param namespace
 *            名称空间
 * @param method
 *            方法名称
 * @return	返回报文结果(xml)
 */
//    public static String loadWebService(String reqXML, String endPoint, String namespace, String method) {
//        String responseXml = "";
//        RPCServiceClient serviceClient = null;
//        try {
//            /* 调用理赔系统的接口 */
//            String nameSpace = namespace;
//            QName qname = new QName(nameSpace, method);
//            serviceClient = new RPCServiceClient();
//            Options options = serviceClient.getOptions();
//            EndpointReference targetEPR = new EndpointReference(endPoint);
//            options.setTo(targetEPR);
//            options.setTimeOutInMilliSeconds(30000);
//            Object[] rtnObjs = serviceClient.invokeBlocking(qname, new Object[] { reqXML },
//                    new Class[] { String.class });
//            responseXml = rtnObjs[0].toString();
//        } catch (Exception e) {
//            e.toString();
//        }
//        return responseXml;
//    }

/**
 * axis方式访问webservice
 *
 * @param
 *            请求的xml的报文
 * @param
 *            webservice的wsdl地址,例如：http://1.202.235.66:7002/webService/PartsService?wsdl
 * @param
 *            调用方法的命名空间
 * @param
 *            调用的方法名
 * @return 返回调用的报文(xml)
 *
 */
//    public static String invokRemoveWSDLByAxis(String reqXML, String endPoint, String namespace, String method) {
//        String responseXML = "";
//        Service service = new Service();
//        try {
//            Call call = (Call) service.createCall();
//            call.setTargetEndpointAddress(endPoint);
//            call.setOperationName(new javax.xml.namespace.QName(namespace, method));
//            call.addParameter("arg0", XMLType.XSD_STRING, ParameterMode.IN);
//            call.setReturnType(XMLType.XSD_STRING);
//            responseXML = (String) call.invoke(new Object[] { reqXML });
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//        return responseXML;
//    }
